pub struct CancelSignal { /* private fields */ }Expand description
Handles cancellations from a PromptHook in an agentic loop.
Upon using CancelSignal::cancel(), the agent loop will terminate early, providing the messages generated so far.
You can additionally add a reason for early termination with CancelSignal::cancel_with_reason().
Implementations
Sourceimpl CancelSignal
impl CancelSignal
pub fn cancel(&self)
pub fn cancel_with_reason(&self, reason: &str)