pub struct NoToolConfig;Expand description
Marker type indicating no tool configuration has been set yet.
This is the default state for a new AgentBuilder. From this state,
you can either:
- Add tools via
.tool(),.tools(),.dynamic_tools(), etc. (transitions toWithBuilderTools) - Set a pre-existing
ToolServerHandlevia.tool_server_handle()(transitions toWithToolServerHandle) - Call
.build()to create an agent with no tools