ChatbotBuilder

Struct ChatbotBuilder 

pub struct ChatbotBuilder<A> { /* private fields */ }
Builder pattern for CLI chatbots.

Example

let chatbot = ChatbotBuilder::new().agent(my_agent).show_usage().build();

chatbot.run().await?;

Implementations

Source

impl ChatbotBuilder<AgentNotSet>

pub fn new() -> ChatbotBuilder<AgentNotSet>

pub fn agent<M>(self, agent: Agent<M>) -> ChatbotBuilder<Agent<M>>
where M: CompletionModel + 'static,

Sets the agent that will be used to drive the CLI interface

Source

impl<A> ChatbotBuilder<A>

pub fn show_usage(self) -> ChatbotBuilder<A>

Sets the show_usage flag, so that after a request the number of tokens in the input and output will be printed

pub fn multi_turn_depth(self, multi_turn_depth: usize) -> ChatbotBuilder<A>

Sets the maximum depth for multi-turn, i.e. toolcalls

Source

impl<M> ChatbotBuilder<Agent<M>>
where M: CompletionModel + 'static,

pub fn build(self) -> Chatbot<M>

Consumes the ChatbotBuilder, returning a Chatbot which can be run