This module provides traits for defining and creating provider clients. Clients are used to create models for completion, embeddings, etc. Dyn-compatible traits have been provided to allow for more provider-agnostic code.
Modules
Macros
- impl_
audio_ generation - impl_
conversion_ traits - Implements the conversion traits for a given struct
- impl_
image_ generation
Enums
Traits
- AsAudio
Generation - Attempt to convert a ProviderClient to a AudioGenerationClient
- AsCompletion
- Attempt to convert a ProviderClient to a CompletionClient
- AsEmbeddings
- Attempt to convert a ProviderClient to a EmbeddingsClient
- AsImage
Generation - Attempt to convert a ProviderClient to a ImageGenerationClient
- AsTranscription
- Attempt to convert a ProviderClient to a TranscriptionClient
- Completion
Client - A provider client with completion capabilities. Clone is required for conversions between client types.
- Embeddings
Client - A provider client with embedding capabilities. Clone is required for conversions between client types.
- Provider
Client - The base ProviderClient trait, facilitates conversion between client types and creating a client from the environment.
- Transcription
Client - A provider client with transcription capabilities. Clone is required for conversions between client types.