Client

Struct Client 

pub struct Client<Ext = Nothing, H = Client> { /* private fields */ }

Implementations

Source

impl<Ext, ExtBuilder, Key, H> Client<Ext, H>
where ExtBuilder: Clone + Default + ProviderBuilder<Output = Ext, ApiKey = Key>, Ext: Provider<Builder = ExtBuilder>, H: Default + HttpClientExt, Key: ApiKey,

pub fn new(api_key: impl Into<Key>) -> Result<Client<Ext, H>, Error>

Source

impl<Ext, H> Client<Ext, H>

pub fn base_url(&self) -> &str

pub fn headers(&self) -> &HeaderMap

pub fn ext(&self) -> &Ext

pub fn with_ext<NewExt>(self, new_ext: NewExt) -> Client<NewExt, H>

Source

impl<Ext, Builder, H> Client<Ext, H>
where H: Default + HttpClientExt, Ext: Provider<Builder = Builder>, Builder: Default + ProviderBuilder,

pub fn builder() -> ClientBuilder<Builder, NeedsApiKey, H>

Source

impl<Ext, H> Client<Ext, H>
where Ext: Provider,

pub fn post<S>(&self, path: S) -> Result<Builder, Error>
where S: AsRef<str>,

pub fn post_sse<S>(&self, path: S) -> Result<Builder, Error>
where S: AsRef<str>,

pub fn get<S>(&self, path: S) -> Result<Builder, Error>
where S: AsRef<str>,

Source

impl<T> Client<CohereExt, T>

pub fn embeddings<D>( &self, model: impl Into<String>, input_type: &str, ) -> EmbeddingsBuilder<EmbeddingModel<T>, D>
where D: Embed,

pub fn embedding_model( &self, model: impl Into<String>, input_type: &str, ) -> EmbeddingModel<T>

Note: default embedding dimension of 0 will be used if model is not known. If this is the case, it’s better to use function embedding_model_with_ndims

pub fn embedding_model_with_ndims( &self, model: impl Into<String>, input_type: &str, ndims: usize, ) -> EmbeddingModel<T>

Create an embedding model with the given name and the number of dimensions in the embedding generated by the model.

Source

impl<T> Client<MiraExt, T>
where T: HttpClientExt + 'static,

pub async fn list_models(&self) -> Result<Vec<String>, MiraError>

List available models

Source

impl<H> Client<OpenAIResponsesExt, H>

pub fn extractor<U>( &self, model: impl Into<String>, ) -> ExtractorBuilder<ResponsesCompletionModel<H>, U>

Create an extractor builder with the given completion model. Uses the OpenAI Responses API (default behavior).

pub fn completions_api(self) -> Client<OpenAICompletionsExt, H>

Create a Completions API client from this Responses API client. Useful for switching to the traditional Chat Completions API.

Source

impl<H> Client<OpenAICompletionsExt, H>

pub fn extractor<U>( &self, model: impl Into<String>, ) -> ExtractorBuilder<CompletionModel<H>, U>

Create an extractor builder with the given completion model. Uses the OpenAI Chat Completions API.

pub fn responses_api(self) -> Client<OpenAIResponsesExt, H>

Create a Responses API client from this Completions API client. Useful for switching to the newer Responses API.