VerifyClientDyn

Trait VerifyClientDyn 

pub trait VerifyClientDyn {
    // Required method
    fn verify(
        &self,
    ) -> Pin<Box<dyn Future<Output = Result<(), VerifyError>> + Send + '_>>;
}
👎Deprecated since 0.25.0: DynClientBuilder and related features have been deprecated and will be removed in a future release. In this case, use VerifyClient instead.

Required Methods

fn verify( &self, ) -> Pin<Box<dyn Future<Output = Result<(), VerifyError>> + Send + '_>>

👎Deprecated since 0.25.0: DynClientBuilder and related features have been deprecated and will be removed in a future release. In this case, use VerifyClient instead.

Verify the configuration.

Implementors

Source

impl<T> VerifyClientDyn for T
where T: VerifyClient,