pub enum UserContent {
Text(Text),
ToolResult(ToolResult),
Image(Image),
Audio(Audio),
Document(Document),
}Expand description
Describes the content of a message, which can be text, a tool result, an image, audio, or a document. Dependent on provider supporting the content type. Multimedia content is generally base64 (defined by it’s format) encoded but additionally supports urls (for some providers).
Variants
Implementations
Sourceimpl UserContent
impl UserContent
Sourcepub fn text(text: impl Into<String>) -> UserContent
pub fn text(text: impl Into<String>) -> UserContent
Helper constructor to make creating user text content easier.
Sourcepub fn image(
data: impl Into<String>,
format: Option<ContentFormat>,
media_type: Option<ImageMediaType>,
detail: Option<ImageDetail>,
) -> UserContent
pub fn image( data: impl Into<String>, format: Option<ContentFormat>, media_type: Option<ImageMediaType>, detail: Option<ImageDetail>, ) -> UserContent
Helper constructor to make creating user image content easier.
Sourcepub fn audio(
data: impl Into<String>,
format: Option<ContentFormat>,
media_type: Option<AudioMediaType>,
) -> UserContent
pub fn audio( data: impl Into<String>, format: Option<ContentFormat>, media_type: Option<AudioMediaType>, ) -> UserContent
Helper constructor to make creating user audio content easier.
Sourcepub fn document(
data: impl Into<String>,
format: Option<ContentFormat>,
media_type: Option<DocumentMediaType>,
) -> UserContent
pub fn document( data: impl Into<String>, format: Option<ContentFormat>, media_type: Option<DocumentMediaType>, ) -> UserContent
Helper constructor to make creating user document content easier.
Sourcepub fn tool_result(
id: impl Into<String>,
content: OneOrMany<ToolResultContent>,
) -> UserContent
pub fn tool_result( id: impl Into<String>, content: OneOrMany<ToolResultContent>, ) -> UserContent
Helper constructor to make creating user tool result content easier.
Sourcepub fn tool_result_with_call_id(
id: impl Into<String>,
call_id: String,
content: OneOrMany<ToolResultContent>,
) -> UserContent
pub fn tool_result_with_call_id( id: impl Into<String>, call_id: String, content: OneOrMany<ToolResultContent>, ) -> UserContent
Helper constructor to make creating user tool result content easier.