pub struct ToolCall {
pub id: String,
pub call_id: Option<String>,
pub function: ToolFunction,
pub signature: Option<String>,
pub additional_params: Option<Value>,
}Expand description
Describes a tool call with an id and function to call, generally produced by a provider.
Fields
id: Stringcall_id: Option<String>function: ToolFunctionsignature: Option<String>Optional cryptographic signature for the tool call.
This field is used by some providers (e.g., Google) to provide a signature that can verify the authenticity and integrity of the tool call. When present, it allows verification that the tool call was actually generated by the model and has not been tampered with.
This is an optional, provider-specific feature and will be None for providers
that don’t support tool call signatures.
additional_params: Option<Value>Additional provider-specific parameters to be sent to the completion model provider
Implementations
Sourceimpl ToolCall
impl ToolCall
pub fn new(id: String, function: ToolFunction) -> ToolCall
pub fn with_call_id(self, call_id: String) -> ToolCall
pub fn with_signature(self, signature: Option<String>) -> ToolCall
pub fn with_additional_params( self, additional_params: Option<Value>, ) -> ToolCall