CompletionResponse

Struct CompletionResponse 

pub struct CompletionResponse<T> {
    pub choice: OneOrMany<AssistantContent>,
    pub usage: Usage,
    pub raw_response: T,
}
General completion response struct that contains the high-level completion choice and the raw response. The completion choice contains one or more assistant content.

Fields

choice: OneOrMany<AssistantContent>

The completion choice (represented by one or more assistant message content) returned by the completion model provider

usage: Usage

Tokens used during prompting and responding

raw_response: T

The raw response returned by the completion model provider