pub struct Usage {
pub input_tokens: u64,
pub output_tokens: u64,
pub total_tokens: u64,
}Expand description
Struct representing the token usage for a completion request.
If tokens used are 0, then the provider failed to supply token usage metrics.
Fields
input_tokens: u64output_tokens: u64total_tokens: u64Implementations