pub struct AzureExt { /* private fields */ }Trait Implementations
Sourceimpl<H> Capabilities<H> for AzureExt
impl<H> Capabilities<H> for AzureExt
type Completion = Capable<CompletionModel<H>>
type Embeddings = Capable<EmbeddingModel<H>>
type Transcription = Capable<TranscriptionModel<H>>
type ModelListing = Nothing
Sourceimpl Provider for AzureExt
impl Provider for AzureExt
Sourceconst VERIFY_PATH: &'static str = ""
const VERIFY_PATH: &'static str = ""
Verifying Azure auth without consuming tokens is not supported
Sourcetype Builder = AzureExtBuilder
type Builder = AzureExtBuilder
The builder type that constructs this provider extension.
This associates extensions with their builders for type inference.
fn build_uri(&self, base_url: &str, path: &str, _transport: Transport) -> String
fn with_custom(&self, req: Builder) -> Result<Builder, Error>