pub struct AzureExtBuilder { /* private fields */ }Trait Implementations
Sourceimpl Clone for AzureExtBuilder
impl Clone for AzureExtBuilder
Sourcefn clone(&self) -> AzureExtBuilder
fn clone(&self) -> AzureExtBuilder
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AzureExtBuilder
impl Debug for AzureExtBuilder
Sourceimpl Default for AzureExtBuilder
impl Default for AzureExtBuilder
Sourcefn default() -> AzureExtBuilder
fn default() -> AzureExtBuilder
Returns the “default value” for a type. Read more
Sourceimpl ProviderBuilder for AzureExtBuilder
impl ProviderBuilder for AzureExtBuilder
const BASE_URL: &'static str = ""
type Extension<H: HttpClientExt> = AzureExt
type ApiKey = AzureOpenAIAuth
Sourcefn build<H>(
builder: &ClientBuilder<AzureExtBuilder, <AzureExtBuilder as ProviderBuilder>::ApiKey, H>,
) -> Result<<AzureExtBuilder as ProviderBuilder>::Extension<H>, Error>where
H: HttpClientExt,
fn build<H>(
builder: &ClientBuilder<AzureExtBuilder, <AzureExtBuilder as ProviderBuilder>::ApiKey, H>,
) -> Result<<AzureExtBuilder as ProviderBuilder>::Extension<H>, Error>where
H: HttpClientExt,
Build the provider extension from the client builder configuration.
Sourcefn finish<H>(
&self,
builder: ClientBuilder<AzureExtBuilder, <AzureExtBuilder as ProviderBuilder>::ApiKey, H>,
) -> Result<ClientBuilder<AzureExtBuilder, <AzureExtBuilder as ProviderBuilder>::ApiKey, H>, Error>
fn finish<H>( &self, builder: ClientBuilder<AzureExtBuilder, <AzureExtBuilder as ProviderBuilder>::ApiKey, H>, ) -> Result<ClientBuilder<AzureExtBuilder, <AzureExtBuilder as ProviderBuilder>::ApiKey, H>, Error>
This method can be used to customize the fields of
builder before it is used to create
a client. For example, adding default headersAuto Trait Implementations
impl Freeze for AzureExtBuilder
impl RefUnwindSafe for AzureExtBuilder
impl Send for AzureExtBuilder
impl Sync for AzureExtBuilder
impl Unpin for AzureExtBuilder
impl UnsafeUnpin for AzureExtBuilder
impl UnwindSafe for AzureExtBuilder