pub struct Client<T = Client> { /* private fields */ }Implementations
Sourceimpl<T> Client<T>
impl<T> Client<T>
pub fn embeddings<D>(
&self,
model: &str,
input_type: &str,
) -> EmbeddingsBuilder<EmbeddingModel<T>, D>where
D: Embed,
Sourcepub fn embedding_model(
&self,
model: &str,
input_type: &str,
) -> EmbeddingModel<T>
pub fn embedding_model( &self, model: &str, input_type: &str, ) -> EmbeddingModel<T>
Note: default embedding dimension of 0 will be used if model is not known.
If this is the case, it’s better to use function embedding_model_with_ndims
Sourcepub fn embedding_model_with_ndims(
&self,
model: &str,
input_type: &str,
ndims: usize,
) -> EmbeddingModel<T>
pub fn embedding_model_with_ndims( &self, model: &str, input_type: &str, ndims: usize, ) -> EmbeddingModel<T>
Create an embedding model with the given name and the number of dimensions in the embedding generated by the model.