pub enum StreamingCompletionChunk {
Response(Box<ResponseChunk>),
Delta(ItemChunk),
}Expand description
A streaming completion chunk. Streaming chunks can come in one of two forms:
- A response chunk (where the completed response will have the total token usage)
- An item chunk commonly referred to as a delta. In the completions API this would be referred to as the message delta.
Variants
Response(Box<ResponseChunk>)
Delta(ItemChunk)