pub struct CompletionRequest {
pub input: OneOrMany<InputItem>,
pub model: String,
pub instructions: Option<String>,
pub max_output_tokens: Option<u64>,
pub stream: Option<bool>,
pub temperature: Option<f64>,
pub tools: Vec<ResponsesToolDefinition>,
pub additional_parameters: AdditionalParameters,
/* private fields */
}Expand description
The completion request type for OpenAI’s Response API: https://platform.openai.com/docs/api-reference/responses/create
Intended to be derived from crate::completion::request::CompletionRequest.
Fields
input: OneOrMany<InputItem>Message inputs
model: StringThe model name
instructions: Option<String>Instructions (also referred to as preamble, although in other APIs this would be the “system prompt”)
max_output_tokens: Option<u64>The maximum number of output tokens.
stream: Option<bool>Toggle to true for streaming responses.
temperature: Option<f64>The temperature. Set higher (up to a max of 1.0) for more creative responses.
tools: Vec<ResponsesToolDefinition>The tools you want to use. Currently this is limited to functions, but will be expanded on in future.
additional_parameters: AdditionalParametersAdditional parameters
Implementations
Sourceimpl CompletionRequest
impl CompletionRequest
pub fn with_structured_outputs<S>( self, schema_name: S, schema: Value, ) -> CompletionRequest
pub fn with_reasoning(self, reasoning: Reasoning) -> CompletionRequest