pub struct OpenRouterExtBuilder;Trait Implementations
Sourceimpl Clone for OpenRouterExtBuilder
impl Clone for OpenRouterExtBuilder
Sourcefn clone(&self) -> OpenRouterExtBuilder
fn clone(&self) -> OpenRouterExtBuilder
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OpenRouterExtBuilder
impl Debug for OpenRouterExtBuilder
Sourceimpl Default for OpenRouterExtBuilder
impl Default for OpenRouterExtBuilder
Sourcefn default() -> OpenRouterExtBuilder
fn default() -> OpenRouterExtBuilder
Returns the “default value” for a type. Read more
Sourceimpl ProviderBuilder for OpenRouterExtBuilder
impl ProviderBuilder for OpenRouterExtBuilder
const BASE_URL: &'static str = OPENROUTER_API_BASE_URL
type Extension<H: HttpClientExt> = OpenRouterExt
type ApiKey = BearerAuth
Sourcefn build<H>(
_builder: &ClientBuilder<OpenRouterExtBuilder, <OpenRouterExtBuilder as ProviderBuilder>::ApiKey, H>,
) -> Result<<OpenRouterExtBuilder as ProviderBuilder>::Extension<H>, Error>where
H: HttpClientExt,
fn build<H>(
_builder: &ClientBuilder<OpenRouterExtBuilder, <OpenRouterExtBuilder as ProviderBuilder>::ApiKey, H>,
) -> Result<<OpenRouterExtBuilder as ProviderBuilder>::Extension<H>, Error>where
H: HttpClientExt,
Build the provider extension from the client builder configuration.
Sourcefn finish<H>(
&self,
builder: ClientBuilder<Self, Self::ApiKey, H>,
) -> Result<ClientBuilder<Self, Self::ApiKey, H>, Error>
fn finish<H>( &self, builder: ClientBuilder<Self, Self::ApiKey, H>, ) -> Result<ClientBuilder<Self, Self::ApiKey, H>, Error>
This method can be used to customize the fields of
builder before it is used to create
a client. For example, adding default headersimpl Copy for OpenRouterExtBuilder