pub struct Client<T = Client> { /* private fields */ }Implementations
Sourceimpl<T> Client<T>where
T: Default,
impl<T> Client<T>where
T: Default,
Sourcepub fn builder(api_key: &str) -> ClientBuilder<'_, T>
pub fn builder(api_key: &str) -> ClientBuilder<'_, T>
Create a new Together AI client builder.
Example
use rig::providers::together_ai::{ClientBuilder, self};
// Initialize the Together AI client
let together_ai = Client::builder("your-together-ai-api-key")
.build()Trait Implementations
Sourceimpl<T> AsTranscription for Client<T>
impl<T> AsTranscription for Client<T>
fn as_transcription(&self) -> Option<Box<dyn TranscriptionClientDyn>>
Sourceimpl CompletionClient for Client
impl CompletionClient for Client
Sourcefn completion_model(&self, model: &str) -> CompletionModel
fn completion_model(&self, model: &str) -> CompletionModel
Create a completion model with the given name.
Sourcetype CompletionModel = CompletionModel
type CompletionModel = CompletionModel
The type of CompletionModel used by the client.
Sourcefn agent(&self, model: &str) -> AgentBuilder<Self::CompletionModel>
fn agent(&self, model: &str) -> AgentBuilder<Self::CompletionModel>
Create an agent builder with the given completion model. Read more
Sourcefn extractor<T>(
&self,
model: &str,
) -> ExtractorBuilder<Self::CompletionModel, T>
fn extractor<T>( &self, model: &str, ) -> ExtractorBuilder<Self::CompletionModel, T>
Create an extractor builder with the given completion model.
Sourceimpl EmbeddingsClient for Client
impl EmbeddingsClient for Client
Sourcefn embedding_model(&self, model: &str) -> EmbeddingModel
fn embedding_model(&self, model: &str) -> EmbeddingModel
Create an embedding model with the given name.
Note: default embedding dimension of 0 will be used if model is not known.
If this is the case, it’s better to use function embedding_model_with_ndims
Example
use rig::providers::together_ai::{Client, self};
// Initialize the Together AI client
let together_ai = Client::new("your-together-ai-api-key");
let embedding_model = together_ai.embedding_model(together_ai::embedding::EMBEDDING_V1);Sourcefn embedding_model_with_ndims(
&self,
model: &str,
ndims: usize,
) -> EmbeddingModel
fn embedding_model_with_ndims( &self, model: &str, ndims: usize, ) -> EmbeddingModel
Create an embedding model with the given name and the number of dimensions in the embedding generated by the model.
Example
use rig::providers::together_ai::{Client, self};
// Initialize the Together AI client
let together_ai = Client::new("your-together-ai-api-key");
let embedding_model = together_ai.embedding_model_with_ndims("model-unknown-to-rig", 1024);Sourcetype EmbeddingModel = EmbeddingModel
type EmbeddingModel = EmbeddingModel
The type of EmbeddingModel used by the Client
Sourcefn embeddings<D>(
&self,
model: &str,
) -> EmbeddingsBuilder<Self::EmbeddingModel, D>where
D: Embed,
fn embeddings<D>(
&self,
model: &str,
) -> EmbeddingsBuilder<Self::EmbeddingModel, D>where
D: Embed,
Create an embedding builder with the given embedding model. Read more
Sourcefn embeddings_with_ndims<D>(
&self,
model: &str,
ndims: usize,
) -> EmbeddingsBuilder<Self::EmbeddingModel, D>where
D: Embed,
fn embeddings_with_ndims<D>(
&self,
model: &str,
ndims: usize,
) -> EmbeddingsBuilder<Self::EmbeddingModel, D>where
D: Embed,
Create an embedding builder with the given name and the number of dimensions in the embedding generated by the model. Read more
Sourceimpl ProviderClient for Client
impl ProviderClient for Client
Sourcefn from_env() -> Client
fn from_env() -> Client
Create a new Together AI client from the TOGETHER_API_KEY environment variable.
Panics if the environment variable is not set.
fn from_val(input: ProviderValue) -> Client
Sourcefn boxed(self) -> Box<dyn ProviderClient>where
Self: Sized + 'static,
fn boxed(self) -> Box<dyn ProviderClient>where
Self: Sized + 'static,
A helper method to box the client.
Sourcefn from_env_boxed<'a>() -> Box<dyn ProviderClient + 'a>where
Self: Sized + 'a,
fn from_env_boxed<'a>() -> Box<dyn ProviderClient + 'a>where
Self: Sized + 'a,
Create a boxed client from the process’s environment.
Panics if an environment is improperly configured.
Sourcefn from_val_boxed<'a>(input: ProviderValue) -> Box<dyn ProviderClient + 'a>where
Self: Sized + 'a,
fn from_val_boxed<'a>(input: ProviderValue) -> Box<dyn ProviderClient + 'a>where
Self: Sized + 'a,
Create a boxed client from the process’s environment.
Panics if an environment is improperly configured.
Sourceimpl VerifyClient for Client
impl VerifyClient for Client