pub enum StreamedAssistantContent<R> {
Text(Text),
ToolCall(ToolCall),
ToolCallDelta {
id: String,
delta: String,
},
Reasoning(Reasoning),
ReasoningDelta {
id: Option<String>,
reasoning: String,
},
Final(R),
}Expand description
Describes responses from a streamed provider response which is either text, a tool call or a final usage response.
Variants
Implementations
Sourceimpl<R> StreamedAssistantContent<R>
impl<R> StreamedAssistantContent<R>
pub fn text(text: &str) -> StreamedAssistantContent<R>
pub fn final_response(res: R) -> StreamedAssistantContent<R>