pub struct ChatbotBuilder<A> { /* private fields */ }Expand description
Builder pattern for CLI chatbots.
Example
let chatbot = ChatbotBuilder::new().agent(my_agent).show_usage().build();
chatbot.run().await?;Implementations
Sourceimpl ChatbotBuilder<AgentNotSet>
impl ChatbotBuilder<AgentNotSet>
pub fn new() -> ChatbotBuilder<AgentNotSet>
Sourcepub fn agent<M>(self, agent: Agent<M>) -> ChatbotBuilder<Agent<M>>where
M: CompletionModel + 'static,
pub fn agent<M>(self, agent: Agent<M>) -> ChatbotBuilder<Agent<M>>where
M: CompletionModel + 'static,
Sets the agent that will be used to drive the CLI interface
Sourceimpl<A> ChatbotBuilder<A>
impl<A> ChatbotBuilder<A>
Sourcepub fn show_usage(self) -> ChatbotBuilder<A>
pub fn show_usage(self) -> ChatbotBuilder<A>
Sets the show_usage flag, so that after a request the number of tokens
in the input and output will be printed
Sourcepub fn multi_turn_depth(self, multi_turn_depth: usize) -> ChatbotBuilder<A>
pub fn multi_turn_depth(self, multi_turn_depth: usize) -> ChatbotBuilder<A>
Sets the maximum depth for multi-turn, i.e. toolcalls
Sourceimpl<M> ChatbotBuilder<Agent<M>>where
M: CompletionModel + 'static,
impl<M> ChatbotBuilder<Agent<M>>where
M: CompletionModel + 'static,