Module client

This module provides traits for defining and creating provider clients. Clients are used to create models for completion, embeddings, etc. Dyn-compatible traits have been provided to allow for more provider-agnostic code.

Modules

audio_generation
builder
completion
embeddings
image_generation
transcription

Macros

impl_audio_generation
impl_conversion_traits
Implements the conversion traits for a given struct
impl_image_generation

Traits

AsAudioGeneration
Attempt to convert a ProviderClient to a AudioGenerationClient
AsCompletion
Attempt to convert a ProviderClient to a CompletionClient
AsEmbeddings
Attempt to convert a ProviderClient to a EmbeddingsClient
AsImageGeneration
Attempt to convert a ProviderClient to a ImageGenerationClient
AsTranscription
Attempt to convert a ProviderClient to a TranscriptionClient
CompletionClient
A provider client with completion capabilities. Clone is required for conversions between client types.
EmbeddingsClient
A provider client with embedding capabilities. Clone is required for conversions between client types.
ProviderClient
The base ProviderClient trait, facilitates conversion between client types and creating a client from the environment.
TranscriptionClient
A provider client with transcription capabilities. Clone is required for conversions between client types.