DynClientBuilder

Struct DynClientBuilder 

pub struct DynClientBuilder(/* private fields */);
👎Deprecated since 0.25.0: DynClientBuilder and related features have been deprecated and will be removed in a future release.

Implementations

Source

impl DynClientBuilder

pub fn new() -> DynClientBuilder

pub fn register<Ext, H, Models>( self, provider_name: &'static str, model: Models, ) -> DynClientBuilder

pub fn from_env<T, Models>( &self, provider_name: &'static str, model: Models, ) -> Result<AnyClient, Error>
where T: 'static, Models: ToString,

pub fn factory<Models>( &self, provider_name: &'static str, model: Models, ) -> Option<&ProviderFactory>
where Models: ToString,

pub fn agent<Models>( &self, provider_name: impl Into<&'static str>, model: Models, ) -> Result<AgentBuilder<CompletionModelHandle<'_>>, Error>
where Models: ToString,

Get a boxed agent based on the provider and model, as well as an API key.

pub fn completion<Models>( &self, provider_name: &'static str, model: Models, ) -> Result<Box<dyn CompletionModelDyn>, Error>
where Models: ToString,

Get a boxed completion model based on the provider and model.

pub fn embeddings<Models>( &self, provider_name: &'static str, model: Models, ) -> Result<Box<dyn EmbeddingModelDyn>, Error>
where Models: ToString,

Get a boxed embedding model based on the provider and model.

pub fn transcription<Models>( &self, provider_name: &'static str, model: Models, ) -> Result<Box<dyn TranscriptionModelDyn>, Error>
where Models: ToString,

Get a boxed transcription model based on the provider and model.

pub async fn stream_completion<Models>( &self, provider_name: &'static str, model: Models, request: CompletionRequest, ) -> Result<StreamingCompletionResponse<FinalCompletionResponse>, Error>
where Models: ToString,

Stream a completion request to the specified provider and model.

pub async fn stream_prompt<Models, Prompt>( &self, provider_name: impl Into<&'static str>, model: Models, prompt: Prompt, ) -> Result<StreamingCompletionResponse<FinalCompletionResponse>, Error>
where Models: ToString, Prompt: Into<Message> + WasmCompatSend,

Stream a simple prompt to the specified provider and model.

pub async fn stream_chat<Models, Prompt>( &self, provider_name: &'static str, model: Models, prompt: Prompt, history: Vec<Message>, ) -> Result<StreamingCompletionResponse<FinalCompletionResponse>, Error>
where Models: ToString, Prompt: Into<Message> + WasmCompatSend,

Stream a chat with history to the specified provider and model.