pub trait CompletionClientDyn {
// Required methods
fn completion_model<'a>(
&self,
model: &str,
) -> Box<dyn CompletionModelDyn + 'a>;
fn agent<'a>(&self, model: &str) -> AgentBuilder<CompletionModelHandle<'a>>;
}👎Deprecated since 0.25.0:
DynClientBuilder and related features have been deprecated and will be removed in a future release. In this case, use CompletionClient instead.
Required Methods
Sourcefn completion_model<'a>(&self, model: &str) -> Box<dyn CompletionModelDyn + 'a>
👎Deprecated since 0.25.0: DynClientBuilder and related features have been deprecated and will be removed in a future release. In this case, use CompletionClient instead.
fn completion_model<'a>(&self, model: &str) -> Box<dyn CompletionModelDyn + 'a>
DynClientBuilder and related features have been deprecated and will be removed in a future release. In this case, use CompletionClient instead.
Create a completion model with the given name.
Sourcefn agent<'a>(&self, model: &str) -> AgentBuilder<CompletionModelHandle<'a>>
👎Deprecated since 0.25.0: DynClientBuilder and related features have been deprecated and will be removed in a future release. In this case, use CompletionClient instead.
fn agent<'a>(&self, model: &str) -> AgentBuilder<CompletionModelHandle<'a>>
DynClientBuilder and related features have been deprecated and will be removed in a future release. In this case, use CompletionClient instead.
Create an agent builder with the given completion model.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".