pub struct Client<Ext = Nothing, H = Client> { /* private fields */ }Implementations
Sourceimpl<Ext, ExtBuilder, Key, H> Client<Ext, H>where
ExtBuilder: Clone + Default + ProviderBuilder<Output = Ext, ApiKey = Key>,
Ext: Provider<Builder = ExtBuilder>,
H: Default + HttpClientExt,
Key: ApiKey,
impl<Ext, ExtBuilder, Key, H> Client<Ext, H>where
ExtBuilder: Clone + Default + ProviderBuilder<Output = Ext, ApiKey = Key>,
Ext: Provider<Builder = ExtBuilder>,
H: Default + HttpClientExt,
Key: ApiKey,
Sourceimpl<Ext, Builder, H> Client<Ext, H>where
H: Default + HttpClientExt,
Ext: Provider<Builder = Builder>,
Builder: Default + ProviderBuilder,
impl<Ext, Builder, H> Client<Ext, H>where
H: Default + HttpClientExt,
Ext: Provider<Builder = Builder>,
Builder: Default + ProviderBuilder,
pub fn builder() -> ClientBuilder<Builder, NeedsApiKey, H>
Sourceimpl<T> Client<CohereExt, T>
impl<T> Client<CohereExt, T>
pub fn embeddings<D>(
&self,
model: impl Into<String>,
input_type: &str,
) -> EmbeddingsBuilder<EmbeddingModel<T>, D>where
D: Embed,
Sourcepub fn embedding_model(
&self,
model: impl Into<String>,
input_type: &str,
) -> EmbeddingModel<T>
pub fn embedding_model( &self, model: impl Into<String>, input_type: &str, ) -> EmbeddingModel<T>
Note: default embedding dimension of 0 will be used if model is not known.
If this is the case, it’s better to use function embedding_model_with_ndims
Sourcepub fn embedding_model_with_ndims(
&self,
model: impl Into<String>,
input_type: &str,
ndims: usize,
) -> EmbeddingModel<T>
pub fn embedding_model_with_ndims( &self, model: impl Into<String>, input_type: &str, ndims: usize, ) -> EmbeddingModel<T>
Create an embedding model with the given name and the number of dimensions in the embedding generated by the model.
Sourceimpl<T> Client<MiraExt, T>where
T: HttpClientExt + 'static,
impl<T> Client<MiraExt, T>where
T: HttpClientExt + 'static,
Sourceimpl<H> Client<OpenAIResponsesExt, H>
impl<H> Client<OpenAIResponsesExt, H>
Sourcepub fn extractor<U>(
&self,
model: impl Into<String>,
) -> ExtractorBuilder<ResponsesCompletionModel<H>, U>
pub fn extractor<U>( &self, model: impl Into<String>, ) -> ExtractorBuilder<ResponsesCompletionModel<H>, U>
Create an extractor builder with the given completion model. Uses the OpenAI Responses API (default behavior).
Sourcepub fn completions_api(self) -> Client<OpenAICompletionsExt, H>
pub fn completions_api(self) -> Client<OpenAICompletionsExt, H>
Create a Completions API client from this Responses API client. Useful for switching to the traditional Chat Completions API.
Sourceimpl<H> Client<OpenAICompletionsExt, H>
impl<H> Client<OpenAICompletionsExt, H>
Sourcepub fn extractor<U>(
&self,
model: impl Into<String>,
) -> ExtractorBuilder<CompletionModel<H>, U>
pub fn extractor<U>( &self, model: impl Into<String>, ) -> ExtractorBuilder<CompletionModel<H>, U>
Create an extractor builder with the given completion model. Uses the OpenAI Chat Completions API.
Sourcepub fn responses_api(self) -> Client<OpenAIResponsesExt, H>
pub fn responses_api(self) -> Client<OpenAIResponsesExt, H>
Create a Responses API client from this Completions API client. Useful for switching to the newer Responses API.