#[non_exhaustive]pub struct Reasoning {
pub id: Option<String>,
pub reasoning: Vec<String>,
pub signature: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>reasoning: Vec<String>signature: Option<String>Optional cryptographic signature for the reasoning content.
This field is used by some providers (e.g., Anthropic) to provide a signature that can verify the authenticity and integrity of the reasoning output. When present, it allows verification that the reasoning content was actually generated by the model and has not been tampered with.
This is an optional, provider-specific feature and will be None for providers
that don’t support reasoning signatures.
Implementations