pub struct Client { /* private fields */ }Implementations
Sourceimpl Client
impl Client
pub fn new(api_key: &str) -> Client
pub fn from_url(api_key: &str, base_url: &str) -> Client
pub fn post(&self, path: &str) -> RequestBuilder
pub fn embeddings<D>(
&self,
model: &str,
input_type: &str,
) -> EmbeddingsBuilder<EmbeddingModel, D>where
D: Embed,
Sourcepub fn embedding_model(&self, model: &str, input_type: &str) -> EmbeddingModel
pub fn embedding_model(&self, model: &str, input_type: &str) -> EmbeddingModel
Note: default embedding dimension of 0 will be used if model is not known.
If this is the case, it’s better to use function embedding_model_with_ndims
Sourcepub fn embedding_model_with_ndims(
&self,
model: &str,
input_type: &str,
ndims: usize,
) -> EmbeddingModel
pub fn embedding_model_with_ndims( &self, model: &str, input_type: &str, ndims: usize, ) -> EmbeddingModel
Create an embedding model with the given name and the number of dimensions in the embedding generated by the model.