pub enum StreamedAssistantContent<R> {
Text(Text),
ToolCall(ToolCall),
Reasoning(Reasoning),
Final(R),
}Expand description
Describes responses from a streamed provider response which is either text, a tool call or a final usage response.
Variants
Implementations
Sourceimpl<R> StreamedAssistantContent<R>
impl<R> StreamedAssistantContent<R>
pub fn text(text: &str) -> StreamedAssistantContent<R>
Sourcepub fn tool_call(
id: impl Into<String>,
name: impl Into<String>,
arguments: Value,
) -> StreamedAssistantContent<R>
pub fn tool_call( id: impl Into<String>, name: impl Into<String>, arguments: Value, ) -> StreamedAssistantContent<R>
Helper constructor to make creating assistant tool call content easier.
pub fn tool_call_with_call_id( id: impl Into<String>, call_id: String, name: impl Into<String>, arguments: Value, ) -> StreamedAssistantContent<R>
pub fn final_response(res: R) -> StreamedAssistantContent<R>